@@ -1,5 +1,5 @@
-      subroutine glkerns(t,x,n,tt,m,nue,kord,ihetero,irnd,
-     .     ismo,m1,tl,tu,s,sig,wn,w1,b,y)
+      subroutine glkerns(t,x,tt,n,m,nue,kord, hetero,isrand,
+     .     smo,m1,tl,tu,s,sig,wn,w1,b,y)
 c----------------------------------------------------------------------*
 c-----------------------------------------------------------------------
 c       Short-version: Oct 1996
@@ -14,26 +14,24 @@ c-----------------------------------------------------------------------
 c  used subroutines: constV, resest, kernel with further subroutines
 c-----------------------------------------------------------------------
 c Args
-      integer n, m, nue,kord, ihetero,irnd,ismo, m1
-      double precision t(n),x(n), tt(m),y(m), tl,tu, s(0:n), sig
-      double precision wn(0:n,5),w1(m1,3),b
+      integer n, m, nue,kord
+      double precision t(n),x(n), tt(m), tl,tu, s(0:n), sig
+      logical hetero, isrand, smo
+      integer m1
+      double precision wn(0:n,5),w1(m1,3), b, y(m)
 c Var
-      logical hetero,isrand,smo, inputs, needsrt
-      integer nyg, i,ii,iil,itt,il,iu,itende,it, j,
-     1  kk,kk2, nn
+      logical inputs, needsrt
+      integer nyg, i,ii,iil,itt,il,iu,itende,it, j, kk,kk2, nn
       double precision bias(2,0:2),vark(2,0:2),fak2(2:4),
      1     rvar, s0,sn, b2,bmin,bmax,bres,bs,alpha,ex,exs,exsvi,
      2     r2,snr,vi,ssi,const,fac, q,tll,tuu, xi,xmy2
 c-
 c-------- 1. initialisations
-      data bias/.2,.04762,.4286,.1515,1.33,.6293/
-      data vark/.6,1.250,2.143,11.93,35.0,381.6/
+      data bias/.2, .04762, .4286, .1515, 1.33, .6293/
+      data vark/.6,  1.250, 2.143, 11.93, 35.0, 381.6/
       data fak2/4.,36.,576./
       nyg=0
       inputs = .false.
-      hetero = ihetero .ne. 0
-      isrand = irnd .ne. 0
-      smo = ismo .ne. 0
 
 c Stop for invalid inputs (impossible when called from R's lokerns())
 
@@ -46,15 +44,18 @@ c     0 <= nue <= 4;  nue <= 2 if(! smo)
 
 c     kord - nue must be even :
       kk=(kord-nue)/2
-      if(2*kk+nue.ne.kord)         kord=nue+2
-      if(kord.gt.4.and. .not.smo)  kord=nue+2
-      if(kord.gt.6.or.kord.le.nue) kord=nue+2
+      if(2*kk + nue .ne. kord)       kord=nue+2
+      if(kord.gt.4 .and. .not.smo)   kord=nue+2
+      if(kord.gt.6 .or. kord.le.nue) kord=nue+2
       if(smo.and.b.le.0) smo=.false.
       rvar=sig
+c- -Wall (erronously warning if not)
+      bmin=1
+      bmax=1
+      ex=1
 
       il=1
       iu=n
-c-
 c-------- 2. computation of s-sequence
       s0=1.5*t(1)-0.5*t(2)
       sn=1.5*t(n)-0.5*t(n-1)
@@ -70,7 +71,7 @@ c-------- 2. computation of s-sequence
          if(smo) goto 160
       end if
 c-
-c-------- 3. computation of minimal, maximal allowed bandwidth
+c-------- 3. computation of minimal, maximal allowed global bandwidth
       bmax=(sn-s0)*.5
       bmin=(sn-s0)/dble(n)*dble(kord-1)*.6
 c-
@@ -88,8 +89,8 @@ c-------- 5. compute indices
       wn(1,1)=0.0
       wn(n,1)=0.0
       do 50 i=1,n
-        if(t(i).le.tl.or.t(i).ge.tu) wn(i,1)=0.0
-        if(t(i).gt.tl.and.t(i).lt.tu) wn(i,1)=1.0
+        if(t(i).le.tl .or.  t(i).ge.tu) wn(i,1)=0.0
+        if(t(i).gt.tl .and. t(i).lt.tu) wn(i,1)=1.0
         if(t(i).lt.tl) il=i+1
         if(t(i).le.tu) iu=i
  50   continue
@@ -141,8 +142,9 @@ c-------- 8. compute constants for iteration
 c-
 c-------- 9. estimating variance and smoothed pseudoresiduals
       rvar=sig
-      if(sig.le..0 .and. .not.hetero)
-     .     call resest(t(il),x(il),nn,wn(il,2),r2,sig)
+      if(sig .le. 0. .and. .not.hetero) then
+        call resest(t(il),x(il),nn,wn(il,2),r2,sig)
+      endif
       if(hetero) then
          call resest(t,x,n,wn(1,2),snr,sig)
          bres=max(bmin,.2*nn**(-.2)*(s(iu)-s(il-1)))
@@ -153,7 +155,8 @@ c-------- 9. estimating variance and smoothed pseudoresiduals
          call kernel(t,wn(1,2),n,bres,0,kk2,nyg,s,
      .        wn(il,3),nn,wn(il,4))
       else
-         call constV(wn(1,4),n,sig)
+c       not hetero
+        call constV(wn(1,4),n,sig)
       end if
 c-
 c-------- 10. [LOOP:] estimate/compute integral constant
@@ -168,14 +171,15 @@ c-------- 11. refinement of s-sequence for random design
           wn(i,5)=dble(i)/dble(n+1)
           wn(i,2)=(dble(i)+.5)/dble(n+1)
           wn(i,3)=wn(i,2)
- 110   continue
+ 110    continue
         exs= -dble(3*kord+1) / dble(6*kord+3)
         exsvi=dble(kord)     / dble(6*kord+3)
         bs=0.1*(vi/(sn-s0)**2)**exsvi * n**exs
         call kernel(wn(1,5),t,n,bs,0,2,nyg,wn(0,3),wn(0,2),n+1,s(0))
-        needsrt=.false.
+
         vi=0.0
-111     do 112 i=1,n
+111     needsrt=.false.
+        do 112 i=1,n
            vi=vi+wn(i,1)*n*(s(i)-s(i-1))**2*wn(i,4)
            if(s(i).lt.s(i-1)) then
               ssi=s(i-1)
@@ -183,7 +187,7 @@ c-------- 11. refinement of s-sequence for random design
               s(i)=ssi
               needsrt=.true.
            end if
- 112    continue
+112     continue
         if(needsrt) goto 111
         if(smo) goto 160
       end if
@@ -245,7 +249,7 @@ c-------- 17. variance check
       end if
       q=sig/rvar
       if(q.le.2.) return
-      if(q.gt.5..and.r2.gt..95) rvar=rvar*.5
+      if(q.gt.5. .and. r2.gt..95) rvar=rvar*.5
       sig=rvar
       call constV(wn(1,4),n,sig)
       goto 100
